==> benchmark-api-1.9.3-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/params/xml/ns/yang/ntfbenchmark/rev150105/TestStatusOutputBuilder.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.ntfbenchmark.rev150105;
import com.google.common.base.MoreObjects;
import java.lang.Class;
import java.lang.Long;
import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.SuppressWarnings;
import java.util.Collections;
import java.util.HashMap;
import java.util.Map;
import java.util.Objects;
import org.opendaylight.yangtools.concepts.Builder;
import org.opendaylight.yangtools.yang.binding.AbstractAugmentable;
import org.opendaylight.yangtools.yang.binding.Augmentation;
import org.opendaylight.yangtools.yang.binding.AugmentationHolder;
import org.opendaylight.yangtools.yang.binding.CodeHelpers;
import org.opendaylight.yangtools.yang.binding.DataObject;
import org.opendaylight.yangtools.yang.common.Uint32;

/**
 * Class that builds {@link TestStatusOutputBuilder} instances. Overall design of the class is that of a
 * <a href="https://en.wikipedia.org/wiki/Fluent_interface">fluent interface</a>, where method chaining is used.
 *
 * <p>
 * In general, this class is supposed to be used like this template:
 * <pre>
 *   <code>
 *     TestStatusOutputBuilder createTarget(int fooXyzzy, int barBaz) {
 *         return new TestStatusOutputBuilderBuilder()
 *             .setFoo(new FooBuilder().setXyzzy(fooXyzzy).build())
 *             .setBar(new BarBuilder().setBaz(barBaz).build())
 *             .build();
 *     }
 *   </code>
 * </pre>
 *
 * <p>
 * This pattern is supported by the immutable nature of TestStatusOutputBuilder, as instances can be freely passed around without
 * worrying about synchronization issues.
 *
 * <p>
 * As a side note: method chaining results in:
 * <ul>
 *   <li>very efficient Java bytecode, as the method invocation result, in this case the Builder reference, is
 *       on the stack, so further method invocations just need to fill method arguments for the next method
 *       invocation, which is terminated by {@link #build()}, which is then returned from the method</li>
 *   <li>better understanding by humans, as the scope of mutable state (the builder) is kept to a minimum and is
 *       very localized</li>
 *   <li>better optimization oportunities, as the object scope is minimized in terms of invocation (rather than
 *       method) stack, making <a href="https://en.wikipedia.org/wiki/Escape_analysis">escape analysis</a> a lot
 *       easier. Given enough compiler (JIT/AOT) prowess, the cost of th builder object can be completely
 *       eliminated</li>
 * </ul>
 *
 * @see TestStatusOutputBuilder
 * @see Builder
 *
 */
public class TestStatusOutputBuilder implements Builder<TestStatusOutput> {

    private TestStatusOutput.ExecStatus _execStatus;
    private Uint32 _ntfCnt;


    Map<Class<? extends Augmentation<TestStatusOutput>>, Augmentation<TestStatusOutput>> augmentation = Collections.emptyMap();

    public TestStatusOutputBuilder() {
    }

    public TestStatusOutputBuilder(TestStatusOutput base) {
        if (base instanceof AugmentationHolder) {
            @SuppressWarnings("unchecked")
            Map<Class<? extends Augmentation<TestStatusOutput>>, Augmentation<TestStatusOutput>> aug =((AugmentationHolder<TestStatusOutput>) base).augmentations();
            if (!aug.isEmpty()) {
                this.augmentation = new HashMap<>(aug);
            }
        }
        this._execStatus = base.getExecStatus();
        this._ntfCnt = base.getNtfCnt();
    }


    public TestStatusOutput.ExecStatus getExecStatus() {
        return _execStatus;
    }
    
    public Uint32 getNtfCnt() {
        return _ntfCnt;
    }

    @SuppressWarnings({ "unchecked", "checkstyle:methodTypeParameterName"})
    public <E$$ extends Augmentation<TestStatusOutput>> E$$ augmentation(Class<E$$> augmentationType) {
        return (E$$) augmentation.get(CodeHelpers.nonNullValue(augmentationType, "augmentationType"));
    }

    
    public TestStatusOutputBuilder setExecStatus(final TestStatusOutput.ExecStatus value) {
        this._execStatus = value;
        return this;
    }
    
    public TestStatusOutputBuilder setNtfCnt(final Uint32 value) {
        this._ntfCnt = value;
        return this;
    }
    
    /**
     * Utility migration setter.
     *
     * @param value field value in legacy type
     * @return this builder
     * @deprecated Use {#link setNtfCnt(Uint32)} instead.
     */
    @Deprecated(forRemoval = true)
    public TestStatusOutputBuilder setNtfCnt(final Long value) {
        return setNtfCnt(CodeHelpers.compatUint(value));
    }
    
    public TestStatusOutputBuilder addAugmentation(Class<? extends Augmentation<TestStatusOutput>> augmentationType, Augmentation<TestStatusOutput> augmentationValue) {
        if (augmentationValue == null) {
            return removeAugmentation(augmentationType);
        }
    
        if (!(this.augmentation instanceof HashMap)) {
            this.augmentation = new HashMap<>();
        }
    
        this.augmentation.put(augmentationType, augmentationValue);
        return this;
    }
    
    public TestStatusOutputBuilder removeAugmentation(Class<? extends Augmentation<TestStatusOutput>> augmentationType) {
        if (this.augmentation instanceof HashMap) {
            this.augmentation.remove(augmentationType);
        }
        return this;
    }

    @Override
    public TestStatusOutput build() {
        return new TestStatusOutputImpl(this);
    }

    private static final class TestStatusOutputImpl
        extends AbstractAugmentable<TestStatusOutput>
        implements TestStatusOutput {
    
        private final TestStatusOutput.ExecStatus _execStatus;
        private final Uint32 _ntfCnt;
    
        TestStatusOutputImpl(TestStatusOutputBuilder base) {
            super(base.augmentation);
            this._execStatus = base.getExecStatus();
            this._ntfCnt = base.getNtfCnt();
        }
    
        @Override
        public TestStatusOutput.ExecStatus getExecStatus() {
            return _execStatus;
        }
        
        @Override
        public Uint32 getNtfCnt() {
            return _ntfCnt;
        }
    
        private int hash = 0;
        private volatile boolean hashValid = false;
        
        @Override
        public int hashCode() {
            if (hashValid) {
                return hash;
            }
        
            final int prime = 31;
            int result = 1;
            result = prime * result + Objects.hashCode(_execStatus);
            result = prime * result + Objects.hashCode(_ntfCnt);
            result = prime * result + Objects.hashCode(augmentations());
        
            hash = result;
            hashValid = true;
            return result;
        }
    
        @Override
        public boolean equals(Object obj) {
            if (this == obj) {
                return true;
            }
            if (!(obj instanceof DataObject)) {
                return false;
            }
            if (!TestStatusOutput.class.equals(((DataObject)obj).implementedInterface())) {
                return false;
            }
            TestStatusOutput other = (TestStatusOutput)obj;
            if (!Objects.equals(_execStatus, other.getExecStatus())) {
                return false;
            }
            if (!Objects.equals(_ntfCnt, other.getNtfCnt())) {
                return false;
            }
            if (getClass() == obj.getClass()) {
                // Simple case: we are comparing against self
                TestStatusOutputImpl otherImpl = (TestStatusOutputImpl) obj;
                if (!Objects.equals(augmentations(), otherImpl.augmentations())) {
                    return false;
                }
            } else {
                // Hard case: compare our augments with presence there...
                for (Map.Entry<Class<? extends Augmentation<TestStatusOutput>>, Augmentation<TestStatusOutput>> e : augmentations().entrySet()) {
                    if (!e.getValue().equals(other.augmentation(e.getKey()))) {
                        return false;
                    }
                }
                // .. and give the other one the chance to do the same
                if (!obj.equals(this)) {
                    return false;
                }
            }
            return true;
        }
    
        @Override
        public String toString() {
            final MoreObjects.ToStringHelper helper = MoreObjects.toStringHelper("TestStatusOutput");
            CodeHelpers.appendValue(helper, "_execStatus", _execStatus);
            CodeHelpers.appendValue(helper, "_ntfCnt", _ntfCnt);
            CodeHelpers.appendValue(helper, "augmentation", augmentations().values());
            return helper.toString();
        }
    }
}

==> benchmark-api-2.0.2-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/params/xml/ns/yang/ntfbenchmark/rev150105/TestStatusOutputBuilder.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.ntfbenchmark.rev150105;
import com.google.common.base.MoreObjects;
import java.lang.Class;
import java.lang.Deprecated;
import java.lang.Long;
import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.SuppressWarnings;
import java.util.Collections;
import java.util.HashMap;
import java.util.Map;
import java.util.Objects;
import org.opendaylight.yangtools.concepts.Builder;
import org.opendaylight.yangtools.yang.binding.AbstractAugmentable;
import org.opendaylight.yangtools.yang.binding.Augmentation;
import org.opendaylight.yangtools.yang.binding.AugmentationHolder;
import org.opendaylight.yangtools.yang.binding.CodeHelpers;
import org.opendaylight.yangtools.yang.binding.DataObject;
import org.opendaylight.yangtools.yang.common.Uint32;

/**
 * Class that builds {@link TestStatusOutputBuilder} instances. Overall design of the class is that of a
 * <a href="https://en.wikipedia.org/wiki/Fluent_interface">fluent interface</a>, where method chaining is used.
 *
 * <p>
 * In general, this class is supposed to be used like this template:
 * <pre>
 *   <code>
 *     TestStatusOutputBuilder createTarget(int fooXyzzy, int barBaz) {
 *         return new TestStatusOutputBuilderBuilder()
 *             .setFoo(new FooBuilder().setXyzzy(fooXyzzy).build())
 *             .setBar(new BarBuilder().setBaz(barBaz).build())
 *             .build();
 *     }
 *   </code>
 * </pre>
 *
 * <p>
 * This pattern is supported by the immutable nature of TestStatusOutputBuilder, as instances can be freely passed around without
 * worrying about synchronization issues.
 *
 * <p>
 * As a side note: method chaining results in:
 * <ul>
 *   <li>very efficient Java bytecode, as the method invocation result, in this case the Builder reference, is
 *       on the stack, so further method invocations just need to fill method arguments for the next method
 *       invocation, which is terminated by {@link #build()}, which is then returned from the method</li>
 *   <li>better understanding by humans, as the scope of mutable state (the builder) is kept to a minimum and is
 *       very localized</li>
 *   <li>better optimization oportunities, as the object scope is minimized in terms of invocation (rather than
 *       method) stack, making <a href="https://en.wikipedia.org/wiki/Escape_analysis">escape analysis</a> a lot
 *       easier. Given enough compiler (JIT/AOT) prowess, the cost of th builder object can be completely
 *       eliminated</li>
 * </ul>
 *
 * @see TestStatusOutputBuilder
 * @see Builder
 *
 */
public class TestStatusOutputBuilder implements Builder<TestStatusOutput> {

    private TestStatusOutput.ExecStatus _execStatus;
    private Uint32 _ntfCnt;


    Map<Class<? extends Augmentation<TestStatusOutput>>, Augmentation<TestStatusOutput>> augmentation = Collections.emptyMap();

    public TestStatusOutputBuilder() {
    }

    public TestStatusOutputBuilder(TestStatusOutput base) {
        if (base instanceof AugmentationHolder) {
            @SuppressWarnings("unchecked")
            Map<Class<? extends Augmentation<TestStatusOutput>>, Augmentation<TestStatusOutput>> aug =((AugmentationHolder<TestStatusOutput>) base).augmentations();
            if (!aug.isEmpty()) {
                this.augmentation = new HashMap<>(aug);
            }
        }
        this._execStatus = base.getExecStatus();
        this._ntfCnt = base.getNtfCnt();
    }


    public TestStatusOutput.ExecStatus getExecStatus() {
        return _execStatus;
    }
    
    public Uint32 getNtfCnt() {
        return _ntfCnt;
    }

    @SuppressWarnings({ "unchecked", "checkstyle:methodTypeParameterName"})
    public <E$$ extends Augmentation<TestStatusOutput>> E$$ augmentation(Class<E$$> augmentationType) {
        return (E$$) augmentation.get(Objects.requireNonNull(augmentationType));
    }

    
    public TestStatusOutputBuilder setExecStatus(final TestStatusOutput.ExecStatus value) {
        this._execStatus = value;
        return this;
    }
    
    public TestStatusOutputBuilder setNtfCnt(final Uint32 value) {
        this._ntfCnt = value;
        return this;
    }
    
    /**
     * Utility migration setter.
     *
     * @param value field value in legacy type
     * @return this builder
     * @deprecated Use {#link setNtfCnt(Uint32)} instead.
     */
    @Deprecated(forRemoval = true)
    public TestStatusOutputBuilder setNtfCnt(final Long value) {
        return setNtfCnt(CodeHelpers.compatUint(value));
    }
    
    /**
      * Add an augmentation to this builder's product.
      *
      * @param augmentation augmentation to be added
      * @return this builder
      * @throws NullPointerException if {@code augmentation} is null
      */
    public TestStatusOutputBuilder addAugmentation(Augmentation<TestStatusOutput> augmentation) {
        return doAddAugmentation(augmentation.implementedInterface(), augmentation);
    }
    
    /**
      * Add or remove an augmentation to this builder's product.
      *
      * @param augmentationType augmentation type to be added or removed
      * @param augmentationValue augmentation value, null if the augmentation type should be removed
      * @return this builder
      * @deprecated Use either {@link #addAugmentation(Augmentation)} or {@link #removeAugmentation(Class)} instead.
      */
    @Deprecated(forRemoval = true)
    public TestStatusOutputBuilder addAugmentation(Class<? extends Augmentation<TestStatusOutput>> augmentationType, Augmentation<TestStatusOutput> augmentationValue) {
        return augmentationValue == null ? removeAugmentation(augmentationType) : doAddAugmentation(augmentationType, augmentationValue);
    }
    
    /**
      * Remove an augmentation from this builder's product. If this builder does not track such an augmentation
      * type, this method does nothing.
      *
      * @param augmentationType augmentation type to be removed
      * @return this builder
      */
    public TestStatusOutputBuilder removeAugmentation(Class<? extends Augmentation<TestStatusOutput>> augmentationType) {
        if (this.augmentation instanceof HashMap) {
            this.augmentation.remove(augmentationType);
        }
        return this;
    }
    
    private TestStatusOutputBuilder doAddAugmentation(Class<? extends Augmentation<TestStatusOutput>> augmentationType, Augmentation<TestStatusOutput> augmentationValue) {
        if (!(this.augmentation instanceof HashMap)) {
            this.augmentation = new HashMap<>();
        }
    
        this.augmentation.put(augmentationType, augmentationValue);
        return this;
    }

    @Override
    public TestStatusOutput build() {
        return new TestStatusOutputImpl(this);
    }

    private static final class TestStatusOutputImpl
        extends AbstractAugmentable<TestStatusOutput>
        implements TestStatusOutput {
    
        private final TestStatusOutput.ExecStatus _execStatus;
        private final Uint32 _ntfCnt;
    
        TestStatusOutputImpl(TestStatusOutputBuilder base) {
            super(base.augmentation);
            this._execStatus = base.getExecStatus();
            this._ntfCnt = base.getNtfCnt();
        }
    
        @Override
        public TestStatusOutput.ExecStatus getExecStatus() {
            return _execStatus;
        }
        
        @Override
        public Uint32 getNtfCnt() {
            return _ntfCnt;
        }
    
        private int hash = 0;
        private volatile boolean hashValid = false;
        
        @Override
        public int hashCode() {
            if (hashValid) {
                return hash;
            }
        
            final int prime = 31;
            int result = 1;
            result = prime * result + Objects.hashCode(_execStatus);
            result = prime * result + Objects.hashCode(_ntfCnt);
            result = prime * result + Objects.hashCode(augmentations());
        
            hash = result;
            hashValid = true;
            return result;
        }
    
        @Override
        public boolean equals(Object obj) {
            if (this == obj) {
                return true;
            }
            if (!(obj instanceof DataObject)) {
                return false;
            }
            if (!TestStatusOutput.class.equals(((DataObject)obj).implementedInterface())) {
                return false;
            }
            TestStatusOutput other = (TestStatusOutput)obj;
            if (!Objects.equals(_execStatus, other.getExecStatus())) {
                return false;
            }
            if (!Objects.equals(_ntfCnt, other.getNtfCnt())) {
                return false;
            }
            if (getClass() == obj.getClass()) {
                // Simple case: we are comparing against self
                TestStatusOutputImpl otherImpl = (TestStatusOutputImpl) obj;
                if (!Objects.equals(augmentations(), otherImpl.augmentations())) {
                    return false;
                }
            } else {
                // Hard case: compare our augments with presence there...
                for (Map.Entry<Class<? extends Augmentation<TestStatusOutput>>, Augmentation<TestStatusOutput>> e : augmentations().entrySet()) {
                    if (!e.getValue().equals(other.augmentation(e.getKey()))) {
                        return false;
                    }
                }
                // .. and give the other one the chance to do the same
                if (!obj.equals(this)) {
                    return false;
                }
            }
            return true;
        }
    
        @Override
        public String toString() {
            final MoreObjects.ToStringHelper helper = MoreObjects.toStringHelper("TestStatusOutput");
            CodeHelpers.appendValue(helper, "_execStatus", _execStatus);
            CodeHelpers.appendValue(helper, "_ntfCnt", _ntfCnt);
            CodeHelpers.appendValue(helper, "augmentation", augmentations().values());
            return helper.toString();
        }
    }
}
